@@ -1,11 +1,13 @@
 #!/bin/sh
 
-which gpg >/dev/null || exit 2
+GPG=${GPG:-gpg}
+
+${GPG} --version 2>/dev/null >/dev/null || exit 2
 
 TEMP_KEYRING=$(mktemp)
 
 run_gpg() {
-    gpg --quiet --no-default-keyring --keyring "${TEMP_KEYRING}" "$@"
+    ${GPG} --quiet --no-default-keyring --keyring "${TEMP_KEYRING}" "$@"
 }
 
 gpg_export() {
