@@ -3,13 +3,21 @@
 # TODO(jelmer): Read python3 setup.py dist_info
 # TODO(jelmer): Check XS-Go-Import-Path
 
+from debian.changelog import Version
 import os
 import sys
 import ruamel.yaml
 from lintian_brush.upstream_metadata import (
+    check_upstream_metadata,
     extend_upstream_metadata,
     guess_upstream_metadata_items,
     )
+from lintian_brush.vcs import sanitize_url as sanitize_vcs_url
+
+
+if not Version(os.environ['CURRENT_VERSION']).debian_revision:
+    # Native package
+    sys.exit(0)
 
 
 try:
@@ -25,8 +33,6 @@ fields = set()
 current_certainty = {k: 'certain' for k in code.keys()}
 for key, value, certainty in guess_upstream_metadata_items(
         '.', trust_package=(os.environ.get('TRUST_PACKAGE') == 'true')):
-    if certainty == 'possible' and minimum_certainty == 'certain':
-        continue
     if key.startswith('X-') or key in ('Name', 'Contact', 'Homepage'):
         continue
     if current_certainty.get(key) != 'certain':
@@ -36,10 +42,24 @@ for key, value, certainty in guess_upstream_metadata_items(
         current_certainty[key] = certainty
 
 extend_upstream_metadata(code, current_certainty)
+if os.environ.get('NET_ACCESS', 'allow') == 'allow':
+    check_upstream_metadata(code, current_certainty)
+
+# Drop everything that is below our minimum certainty
+for key, certainty in list(current_certainty.items()):
+    if certainty == 'possible' and minimum_certainty == 'certain':
+        del code[key]
+        del current_certainty[key]
 
 achieved_certainty = (
     'possible' if 'possible' in current_certainty.values() else 'certain')
 
+if 'Repository' in code:
+    new_repository = sanitize_vcs_url(code['Repository'])
+    if new_repository != code['Repository']:
+        code['Repository'] = new_repository
+        fields.add('Repository')
+
 if not fields:
     sys.exit(0)
 
