@@ -49,11 +49,13 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 38)
+__version__ = (0, 39)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
 USER_AGENT = 'lintian-brush/' + version_string
+# Too aggressive?
+DEFAULT_URLLIB_TIMEOUT = 3
 
 
 class NoChanges(Exception):
@@ -223,9 +225,13 @@ class PythonScriptFixer(Fixer):
             old_cwd = os.getcwd()
             try:
                 os.chdir(basedir)
+                global_vars = {
+                    "__file__": self.script_path,
+                    "__name__": "__main__",
+                    }
                 with open(self.script_path, 'r') as f:
                     code = compile(f.read(), self.script_path, 'exec')
-                    exec(code, {})
+                    exec(code, global_vars)
             except FormattingUnpreservable:
                 raise
             except SystemExit as e:
